# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: insightproto/proto/common/v1/common.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'insightproto/proto/common/v1/common.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import descriptor_pb2 as google_dot_protobuf_dot_descriptor__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n)insightproto/proto/common/v1/common.proto\x12\x1cinsightproto.proto.common.v1\x1a google/protobuf/descriptor.proto\"0\n\x06Source\x12\n\n\x02id\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x0c\n\x04type\x18\x03 \x01(\t\"\x1a\n\x0cOrganisation\x12\n\n\x02id\x18\x01 \x01(\t:-\n\x04tags\x12\x1d.google.protobuf.FieldOptions\x18\xc3\xe0\x33 \x01(\tB1Z/github.com/opentrace/insight-proto-go/common/v1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'insightproto.proto.common.v1.common_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z/github.com/opentrace/insight-proto-go/common/v1'
  _globals['_SOURCE']._serialized_start=109
  _globals['_SOURCE']._serialized_end=157
  _globals['_ORGANISATION']._serialized_start=159
  _globals['_ORGANISATION']._serialized_end=185
# @@protoc_insertion_point(module_scope)
