# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: insightproto/proto/results/v1/results.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'insightproto/proto/results/v1/results.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from insightproto.proto.common.v1 import common_pb2 as insightproto_dot_proto_dot_common_dot_v1_dot_common__pb2
from insightproto.proto.jobs.v1 import jobs_pb2 as insightproto_dot_proto_dot_jobs_dot_v1_dot_jobs__pb2
from insightproto.proto.results.v1 import timeline_details_pb2 as insightproto_dot_proto_dot_results_dot_v1_dot_timeline__details__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n+insightproto/proto/results/v1/results.proto\x12\x1dinsightproto.proto.results.v1\x1a\x1fgoogle/protobuf/timestamp.proto\x1a)insightproto/proto/common/v1/common.proto\x1a%insightproto/proto/jobs/v1/jobs.proto\x1a\x34insightproto/proto/results/v1/timeline_details.proto\"\xd3\x07\n\x13InvestigationResult\x12\n\n\x02id\x18\x01 \x01(\t\x12\x37\n\x03org\x18\x02 \x01(\x0b\x32*.insightproto.proto.common.v1.Organisation\x12t\n\x10\x61lert_extraction\x18\x03 \x01(\x0b\x32..insightproto.proto.results.v1.AlertExtractionB*\x9a\x84\x9e\x03%firestore:\"alertExtraction,omitempty\"\x12\x63\n\x08timeline\x18\x04 \x03(\x0b\x32,.insightproto.proto.results.v1.TimelineEventB#\x9a\x84\x9e\x03\x1e\x66irestore:\"timeline,omitempty\"\x12\x64\n\nhypotheses\x18\x05 \x03(\x0b\x32).insightproto.proto.results.v1.HypothesisB%\x9a\x84\x9e\x03 firestore:\"hypotheses,omitempty\"\x12\x34\n\x07trigger\x18\x06 \x01(\x0b\x32#.insightproto.proto.jobs.v1.Trigger\x12^\n\x08metadata\x18\x07 \x01(\x0b\x32\'.insightproto.proto.results.v1.MetaDataB#\x9a\x84\x9e\x03\x1e\x66irestore:\"metadata,omitempty\"\x12S\n\tcreatedAt\x18\x08 \x01(\x0b\x32\x1a.google.protobuf.TimestampB$\x9a\x84\x9e\x03\x1f\x66irestore:\"createdAt,omitempty\"\x12S\n\tupdatedAt\x18\t \x01(\x0b\x32\x1a.google.protobuf.TimestampB$\x9a\x84\x9e\x03\x1f\x66irestore:\"updatedAt,omitempty\"\x12Q\n\x08\x63losedAt\x18\n \x01(\x0b\x32\x1a.google.protobuf.TimestampB#\x9a\x84\x9e\x03\x1e\x66irestore:\"closedAt,omitempty\"\x12]\n\x0e\x61gentTimestamp\x18\x0b \x01(\x0b\x32\x1a.google.protobuf.TimestampB)\x9a\x84\x9e\x03$firestore:\"agentTimestamp,omitempty\"\x12\r\n\x05title\x18\x0c \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\r \x01(\t\x12\x0e\n\x06status\x18\x0e \x01(\t\x12\x10\n\x08priority\x18\x0f \x01(\t\"\xbd\x02\n\x08MetaData\x12\x33\n\x05\x61gent\x18\x01 \x01(\x0b\x32$.insightproto.proto.results.v1.Agent\x12-\n\tstartTime\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12+\n\x07\x65ndTime\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x11\n\ttoolCalls\x18\x04 \x01(\x05\x12\x18\n\x10phase2Iterations\x18\x05 \x01(\x05\x12\x38\n\x04mcps\x18\x06 \x03(\x0b\x32*.insightproto.proto.results.v1.MCPCategory\x12\x39\n\x06tokens\x18\x07 \x03(\x0b\x32).insightproto.proto.results.v1.TokenUsage\"H\n\nTokenUsage\x12\r\n\x05model\x18\x01 \x01(\t\x12\r\n\x05input\x18\x02 \x01(\x03\x12\x0e\n\x06output\x18\x03 \x01(\x03\x12\x0c\n\x04\x63ost\x18\x04 \x01(\x01\"0\n\x0bMCPCategory\x12\x10\n\x08\x63\x61tegory\x18\x01 \x01(\t\x12\x0f\n\x07servers\x18\x02 \x03(\t\"&\n\x05\x41gent\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x0f\n\x07version\x18\x02 \x01(\t\"n\n\x0f\x41lertExtraction\x12-\n\ttimestamp\x18\x01 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\r\n\x05title\x18\x02 \x01(\t\x12\x0f\n\x07summary\x18\x03 \x01(\t\x12\x0c\n\x04tags\x18\x04 \x03(\t\"\xde\r\n\rTimelineEvent\x12-\n\ttimestamp\x18\x01 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x0f\n\x07summary\x18\x02 \x01(\t\x12\x34\n\x06source\x18\x03 \x01(\x0b\x32$.insightproto.proto.common.v1.Source\x12k\n\nimportance\x18\x04 \x01(\x0e\x32..insightproto.proto.results.v1.ImportanceLevelB\'\x18\x01\x9a\x84\x9e\x03 firestore:\"importance,omitempty\"\x12\x33\n\x0f\x61gent_timestamp\x18\x05 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12g\n\nlog_detail\x18\x06 \x01(\x0b\x32(.insightproto.proto.results.v1.LogDetailB$\x9a\x84\x9e\x03\x1f\x66irestore:\"logDetail,omitempty\"H\x00\x88\x01\x01\x12j\n\x0b\x63ode_detail\x18\x07 \x01(\x0b\x32).insightproto.proto.results.v1.CodeDetailB%\x9a\x84\x9e\x03 firestore:\"codeDetail,omitempty\"H\x01\x88\x01\x01\x12\x83\x01\n\x14merge_request_detail\x18\x08 \x01(\x0b\x32\x31.insightproto.proto.results.v1.MergeRequestDetailB-\x9a\x84\x9e\x03(firestore:\"mergeRequestDetail,omitempty\"H\x02\x88\x01\x01\x12\x64\n\tci_detail\x18\t \x01(\x0b\x32\'.insightproto.proto.results.v1.CIDetailB#\x9a\x84\x9e\x03\x1e\x66irestore:\"ciDetail,omitempty\"H\x03\x88\x01\x01\x12y\n\x10knowledge_detail\x18\n \x01(\x0b\x32..insightproto.proto.results.v1.KnowledgeDetailB*\x9a\x84\x9e\x03%firestore:\"knowledgeDetail,omitempty\"H\x04\x88\x01\x01\x12p\n\rticket_detail\x18\x0b \x01(\x0b\x32+.insightproto.proto.results.v1.TicketDetailB\'\x9a\x84\x9e\x03\"firestore:\"ticketDetail,omitempty\"H\x05\x88\x01\x01\x12s\n\x0etrigger_detail\x18\x0c \x01(\x0b\x32,.insightproto.proto.results.v1.TriggerDetailB(\x9a\x84\x9e\x03#firestore:\"triggerDetail,omitempty\"H\x06\x88\x01\x01\x12s\n\x0egeneric_detail\x18\r \x01(\x0b\x32,.insightproto.proto.results.v1.GenericDetailB(\x9a\x84\x9e\x03#firestore:\"genericDetail,omitempty\"H\x07\x88\x01\x01\x12p\n\rmetric_detail\x18\x0e \x01(\x0b\x32+.insightproto.proto.results.v1.MetricDetailB\'\x9a\x84\x9e\x03\"firestore:\"metricDetail,omitempty\"H\x08\x88\x01\x01\x12\r\n\x05query\x18\x0f \x01(\t\x12\n\n\x02id\x18\x10 \x01(\t\x12\x12\n\nhypothesis\x18\x11 \x01(\t\x12^\n\x11importanceMapping\x18\x12 \x03(\x0b\x32\x43.insightproto.proto.results.v1.TimelineEvent.ImportanceMappingEntry\x12\r\n\x05title\x18\x13 \x01(\t\x1ah\n\x16ImportanceMappingEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12=\n\x05value\x18\x02 \x01(\x0e\x32..insightproto.proto.results.v1.ImportanceLevel:\x02\x38\x01\x42\r\n\x0b_log_detailB\x0e\n\x0c_code_detailB\x17\n\x15_merge_request_detailB\x0c\n\n_ci_detailB\x13\n\x11_knowledge_detailB\x10\n\x0e_ticket_detailB\x11\n\x0f_trigger_detailB\x11\n\x0f_generic_detailB\x10\n\x0e_metric_detail\"\x8d\x03\n\nHypothesis\x12\x13\n\x0b\x64\x65scription\x18\x01 \x01(\t\x12\x12\n\nconfidence\x18\x02 \x01(\r\x12L\n\x13supporting_evidence\x18\x03 \x03(\tB/\x18\x01\x9a\x84\x9e\x03(firestore:\"supportingEvidence,omitempty\"\x12N\n\x14timeline_correlation\x18\x04 \x03(\tB0\x18\x01\x9a\x84\x9e\x03)firestore:\"timelineCorrelation,omitempty\"\x12\x45\n\x0frecommendations\x18\x05 \x03(\tB,\x18\x01\x9a\x84\x9e\x03%firestore:\"recommendations,omitempty\"\x12\r\n\x05title\x18\x06 \x01(\t\x12\n\n\x02id\x18\x07 \x01(\t\x12\x14\n\x0c\x63orrelations\x18\x08 \x03(\t\x12@\n\x0cremediations\x18\t \x03(\x0b\x32*.insightproto.proto.results.v1.Remediation\"R\n\x0bRemediation\x12\r\n\x05title\x18\x01 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x02 \x01(\t\x12\r\n\x05tasks\x18\x03 \x03(\t\x12\x10\n\x08\x65stimate\x18\x04 \x01(\t*\xa4\x01\n\x0fImportanceLevel\x12 \n\x1cIMPORTANCE_LEVEL_UNSPECIFIED\x10\x00\x12\x18\n\x14IMPORTANCE_LEVEL_LOW\x10\x01\x12\x1b\n\x17IMPORTANCE_LEVEL_MEDIUM\x10\x02\x12\x19\n\x15IMPORTANCE_LEVEL_HIGH\x10\x03\x12\x1d\n\x19IMPORTANCE_LEVEL_CRITICAL\x10\x04\x42\x32Z0github.com/opentrace/insight-proto-go/results/v1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'insightproto.proto.results.v1.results_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z0github.com/opentrace/insight-proto-go/results/v1'
  _globals['_INVESTIGATIONRESULT'].fields_by_name['alert_extraction']._loaded_options = None
  _globals['_INVESTIGATIONRESULT'].fields_by_name['alert_extraction']._serialized_options = b'\232\204\236\003%firestore:\"alertExtraction,omitempty\"'
  _globals['_INVESTIGATIONRESULT'].fields_by_name['timeline']._loaded_options = None
  _globals['_INVESTIGATIONRESULT'].fields_by_name['timeline']._serialized_options = b'\232\204\236\003\036firestore:\"timeline,omitempty\"'
  _globals['_INVESTIGATIONRESULT'].fields_by_name['hypotheses']._loaded_options = None
  _globals['_INVESTIGATIONRESULT'].fields_by_name['hypotheses']._serialized_options = b'\232\204\236\003 firestore:\"hypotheses,omitempty\"'
  _globals['_INVESTIGATIONRESULT'].fields_by_name['metadata']._loaded_options = None
  _globals['_INVESTIGATIONRESULT'].fields_by_name['metadata']._serialized_options = b'\232\204\236\003\036firestore:\"metadata,omitempty\"'
  _globals['_INVESTIGATIONRESULT'].fields_by_name['createdAt']._loaded_options = None
  _globals['_INVESTIGATIONRESULT'].fields_by_name['createdAt']._serialized_options = b'\232\204\236\003\037firestore:\"createdAt,omitempty\"'
  _globals['_INVESTIGATIONRESULT'].fields_by_name['updatedAt']._loaded_options = None
  _globals['_INVESTIGATIONRESULT'].fields_by_name['updatedAt']._serialized_options = b'\232\204\236\003\037firestore:\"updatedAt,omitempty\"'
  _globals['_INVESTIGATIONRESULT'].fields_by_name['closedAt']._loaded_options = None
  _globals['_INVESTIGATIONRESULT'].fields_by_name['closedAt']._serialized_options = b'\232\204\236\003\036firestore:\"closedAt,omitempty\"'
  _globals['_INVESTIGATIONRESULT'].fields_by_name['agentTimestamp']._loaded_options = None
  _globals['_INVESTIGATIONRESULT'].fields_by_name['agentTimestamp']._serialized_options = b'\232\204\236\003$firestore:\"agentTimestamp,omitempty\"'
  _globals['_TIMELINEEVENT_IMPORTANCEMAPPINGENTRY']._loaded_options = None
  _globals['_TIMELINEEVENT_IMPORTANCEMAPPINGENTRY']._serialized_options = b'8\001'
  _globals['_TIMELINEEVENT'].fields_by_name['importance']._loaded_options = None
  _globals['_TIMELINEEVENT'].fields_by_name['importance']._serialized_options = b'\030\001\232\204\236\003 firestore:\"importance,omitempty\"'
  _globals['_TIMELINEEVENT'].fields_by_name['log_detail']._loaded_options = None
  _globals['_TIMELINEEVENT'].fields_by_name['log_detail']._serialized_options = b'\232\204\236\003\037firestore:\"logDetail,omitempty\"'
  _globals['_TIMELINEEVENT'].fields_by_name['code_detail']._loaded_options = None
  _globals['_TIMELINEEVENT'].fields_by_name['code_detail']._serialized_options = b'\232\204\236\003 firestore:\"codeDetail,omitempty\"'
  _globals['_TIMELINEEVENT'].fields_by_name['merge_request_detail']._loaded_options = None
  _globals['_TIMELINEEVENT'].fields_by_name['merge_request_detail']._serialized_options = b'\232\204\236\003(firestore:\"mergeRequestDetail,omitempty\"'
  _globals['_TIMELINEEVENT'].fields_by_name['ci_detail']._loaded_options = None
  _globals['_TIMELINEEVENT'].fields_by_name['ci_detail']._serialized_options = b'\232\204\236\003\036firestore:\"ciDetail,omitempty\"'
  _globals['_TIMELINEEVENT'].fields_by_name['knowledge_detail']._loaded_options = None
  _globals['_TIMELINEEVENT'].fields_by_name['knowledge_detail']._serialized_options = b'\232\204\236\003%firestore:\"knowledgeDetail,omitempty\"'
  _globals['_TIMELINEEVENT'].fields_by_name['ticket_detail']._loaded_options = None
  _globals['_TIMELINEEVENT'].fields_by_name['ticket_detail']._serialized_options = b'\232\204\236\003\"firestore:\"ticketDetail,omitempty\"'
  _globals['_TIMELINEEVENT'].fields_by_name['trigger_detail']._loaded_options = None
  _globals['_TIMELINEEVENT'].fields_by_name['trigger_detail']._serialized_options = b'\232\204\236\003#firestore:\"triggerDetail,omitempty\"'
  _globals['_TIMELINEEVENT'].fields_by_name['generic_detail']._loaded_options = None
  _globals['_TIMELINEEVENT'].fields_by_name['generic_detail']._serialized_options = b'\232\204\236\003#firestore:\"genericDetail,omitempty\"'
  _globals['_TIMELINEEVENT'].fields_by_name['metric_detail']._loaded_options = None
  _globals['_TIMELINEEVENT'].fields_by_name['metric_detail']._serialized_options = b'\232\204\236\003\"firestore:\"metricDetail,omitempty\"'
  _globals['_HYPOTHESIS'].fields_by_name['supporting_evidence']._loaded_options = None
  _globals['_HYPOTHESIS'].fields_by_name['supporting_evidence']._serialized_options = b'\030\001\232\204\236\003(firestore:\"supportingEvidence,omitempty\"'
  _globals['_HYPOTHESIS'].fields_by_name['timeline_correlation']._loaded_options = None
  _globals['_HYPOTHESIS'].fields_by_name['timeline_correlation']._serialized_options = b'\030\001\232\204\236\003)firestore:\"timelineCorrelation,omitempty\"'
  _globals['_HYPOTHESIS'].fields_by_name['recommendations']._loaded_options = None
  _globals['_HYPOTHESIS'].fields_by_name['recommendations']._serialized_options = b'\030\001\232\204\236\003%firestore:\"recommendations,omitempty\"'
  _globals['_IMPORTANCELEVEL']._serialized_start=4071
  _globals['_IMPORTANCELEVEL']._serialized_end=4235
  _globals['_INVESTIGATIONRESULT']._serialized_start=248
  _globals['_INVESTIGATIONRESULT']._serialized_end=1227
  _globals['_METADATA']._serialized_start=1230
  _globals['_METADATA']._serialized_end=1547
  _globals['_TOKENUSAGE']._serialized_start=1549
  _globals['_TOKENUSAGE']._serialized_end=1621
  _globals['_MCPCATEGORY']._serialized_start=1623
  _globals['_MCPCATEGORY']._serialized_end=1671
  _globals['_AGENT']._serialized_start=1673
  _globals['_AGENT']._serialized_end=1711
  _globals['_ALERTEXTRACTION']._serialized_start=1713
  _globals['_ALERTEXTRACTION']._serialized_end=1823
  _globals['_TIMELINEEVENT']._serialized_start=1826
  _globals['_TIMELINEEVENT']._serialized_end=3584
  _globals['_TIMELINEEVENT_IMPORTANCEMAPPINGENTRY']._serialized_start=3315
  _globals['_TIMELINEEVENT_IMPORTANCEMAPPINGENTRY']._serialized_end=3419
  _globals['_HYPOTHESIS']._serialized_start=3587
  _globals['_HYPOTHESIS']._serialized_end=3984
  _globals['_REMEDIATION']._serialized_start=3986
  _globals['_REMEDIATION']._serialized_end=4068
# @@protoc_insertion_point(module_scope)
