# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: insightproto/proto/results/v1/timeline_details.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'insightproto/proto/results/v1/timeline_details.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from insightproto.proto.jobs.v1 import jobs_pb2 as insightproto_dot_proto_dot_jobs_dot_v1_dot_jobs__pb2
from insightproto.proto.common.v1 import common_pb2 as insightproto_dot_proto_dot_common_dot_v1_dot_common__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n4insightproto/proto/results/v1/timeline_details.proto\x12\x1dinsightproto.proto.results.v1\x1a\x1fgoogle/protobuf/timestamp.proto\x1a%insightproto/proto/jobs/v1/jobs.proto\x1a)insightproto/proto/common/v1/common.proto\"\xc2\x01\n\x08LogEntry\x12&\n\x02ts\x18\x01 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x0b\n\x03msg\x18\x02 \x01(\t\x12\x43\n\x06labels\x18\x03 \x03(\x0b\x32\x33.insightproto.proto.results.v1.LogEntry.LabelsEntry\x12\r\n\x05level\x18\x04 \x01(\t\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\x8e\x01\n\tLogDetail\x12\x35\n\x04logs\x18\x02 \x03(\x0b\x32\'.insightproto.proto.results.v1.LogEntry\x12\r\n\x05query\x18\x03 \x01(\t\x12-\n\x04text\x18\x04 \x01(\tB\x1f\x9a\x84\x9e\x03\x1a\x66irestore:\"text,omitempty\"\x12\x0c\n\x04link\x18\x05 \x01(\t\"\xbb\x03\n\x0b\x41nnotations\x12\n\n\x02id\x18\x01 \x01(\t\x12\x0c\n\x04type\x18\x02 \x01(\t\x12\x63\n\x0fstart_timestamp\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.TimestampB)\x9a\x84\x9e\x03$firestore:\"startTimestamp,omitempty\"H\x00\x88\x01\x01\x12_\n\rend_timestamp\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.TimestampB\'\x9a\x84\x9e\x03\"firestore:\"endTimestamp,omitempty\"H\x01\x88\x01\x01\x12\r\n\x05label\x18\x05 \x01(\t\x12\r\n\x05\x63olor\x18\x06 \x01(\t\x12\x34\n\x05value\x18\x07 \x01(\x02\x42 \x9a\x84\x9e\x03\x1b\x66irestore:\"value,omitempty\"H\x02\x88\x01\x01\x12:\n\ty_axis_id\x18\x08 \x01(\tB\"\x9a\x84\x9e\x03\x1d\x66irestore:\"yAxisId,omitempty\"H\x03\x88\x01\x01\x42\x12\n\x10_start_timestampB\x10\n\x0e_end_timestampB\x08\n\x06_valueB\x0c\n\n_y_axis_id\"\xe1\x01\n\x06Series\x12\x10\n\x08\x64\x61ta_key\x18\x01 \x01(\t\x12\r\n\x05label\x18\x02 \x01(\t\x12\x0c\n\x04type\x18\x03 \x01(\t\x12\x11\n\ty_axis_id\x18\x04 \x01(\t\x12\x14\n\x0cstroke_width\x18\x05 \x01(\x05\x12\r\n\x05\x63olor\x18\x06 \x01(\t\x12\x41\n\x06labels\x18\x07 \x03(\x0b\x32\x31.insightproto.proto.results.v1.Series.LabelsEntry\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\xaa\x01\n\nMetricData\x12&\n\x02ts\x18\x01 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x45\n\x06values\x18\x02 \x03(\x0b\x32\x35.insightproto.proto.results.v1.MetricData.ValuesEntry\x1a-\n\x0bValuesEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"?\n\x06Layout\x12\x19\n\x11left_x_axis_label\x18\x01 \x01(\t\x12\x1a\n\x12right_y_axis_label\x18\x02 \x01(\t\"\x84\x03\n\x0cMetricDetail\x12\r\n\x05query\x18\x03 \x01(\t\x12-\n\x04text\x18\x06 \x01(\tB\x1f\x9a\x84\x9e\x03\x1a\x66irestore:\"text,omitempty\"\x12\x0c\n\x04link\x18\x07 \x01(\t\x12\r\n\x05title\x18\x08 \x01(\t\x12?\n\x0b\x61nnotations\x18\t \x03(\x0b\x32*.insightproto.proto.results.v1.Annotations\x12\x35\n\x06series\x18\n \x03(\x0b\x32%.insightproto.proto.results.v1.Series\x12\x37\n\x04\x64\x61ta\x18\x0b \x03(\x0b\x32).insightproto.proto.results.v1.MetricData\x12]\n\x06layout\x18\x0c \x01(\x0b\x32%.insightproto.proto.results.v1.LayoutB!\x9a\x84\x9e\x03\x1c\x66irestore:\"layout,omitempty\"H\x00\x88\x01\x01\x42\t\n\x07_layout\"1\n\x04User\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x0c\n\x04user\x18\x02 \x01(\t\x12\r\n\x05image\x18\x03 \x01(\t\"\x84\x02\n\nCodeDetail\x12\x11\n\tfile_name\x18\x02 \x01(\t\x12\x11\n\tfile_path\x18\x03 \x01(\t\x12\x11\n\tfile_type\x18\x04 \x01(\t\x12\x12\n\nline_start\x18\x05 \x01(\x05\x12\x0c\n\x04\x63ode\x18\x06 \x01(\t\x12\x0e\n\x06\x63ommit\x18\x07 \x01(\t\x12\x33\n\x06\x61uthor\x18\x08 \x01(\x0b\x32#.insightproto.proto.results.v1.User\x12-\n\x04text\x18\t \x01(\tB\x1f\x9a\x84\x9e\x03\x1a\x66irestore:\"text,omitempty\"\x12\x0c\n\x04link\x18\n \x01(\t\x12\x19\n\x11highlighted_lines\x18\x0b \x03(\x05\"\xa6\x02\n\x12MergeRequestDetail\x12\x33\n\x06\x61uthor\x18\x02 \x01(\x0b\x32#.insightproto.proto.results.v1.User\x12\x36\n\tapprovers\x18\x03 \x03(\x0b\x32#.insightproto.proto.results.v1.User\x12*\n\x06opened\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12*\n\x06merged\x18\x05 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x0e\n\x06status\x18\x06 \x01(\t\x12-\n\x04text\x18\x07 \x01(\tB\x1f\x9a\x84\x9e\x03\x1a\x66irestore:\"text,omitempty\"\x12\x0c\n\x04link\x18\x08 \x01(\t\"y\n\x08\x43IDetail\x12\x13\n\x0bpipeline_id\x18\x02 \x01(\t\x12\x0e\n\x06job_id\x18\x03 \x01(\t\x12\x0b\n\x03log\x18\x04 \x01(\t\x12-\n\x04text\x18\x05 \x01(\tB\x1f\x9a\x84\x9e\x03\x1a\x66irestore:\"text,omitempty\"\x12\x0c\n\x04link\x18\x06 \x01(\t\"N\n\x0fKnowledgeDetail\x12-\n\x04text\x18\x02 \x01(\tB\x1f\x9a\x84\x9e\x03\x1a\x66irestore:\"text,omitempty\"\x12\x0c\n\x04link\x18\x03 \x01(\t\"\xb5\x01\n\x0cTicketDetail\x12\x12\n\nproject_id\x18\x02 \x01(\t\x12\x11\n\tticket_id\x18\x03 \x01(\t\x12\x0c\n\x04tags\x18\x04 \x03(\t\x12\x33\n\x06\x61uthor\x18\x05 \x01(\x0b\x32#.insightproto.proto.results.v1.User\x12-\n\x04text\x18\x06 \x01(\tB\x1f\x9a\x84\x9e\x03\x1a\x66irestore:\"text,omitempty\"\x12\x0c\n\x04link\x18\x07 \x01(\t\"\xc2\x01\n\rTriggerDetail\x12>\n\x0etrigger_source\x18\x02 \x01(\tB&\x18\x01\x9a\x84\x9e\x03\x1f\x66irestore:\"logDetail,omitempty\"\x12\x34\n\x07trigger\x18\x03 \x01(\x0b\x32#.insightproto.proto.jobs.v1.Trigger\x12-\n\x04text\x18\x04 \x01(\tB\x1f\x9a\x84\x9e\x03\x1a\x66irestore:\"text,omitempty\"\x12\x0c\n\x04link\x18\x05 \x01(\t\"L\n\rGenericDetail\x12-\n\x04text\x18\x02 \x01(\tB\x1f\x9a\x84\x9e\x03\x1a\x66irestore:\"text,omitempty\"\x12\x0c\n\x04link\x18\x03 \x01(\tB2Z0github.com/opentrace/insight-proto-go/results/v1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'insightproto.proto.results.v1.timeline_details_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z0github.com/opentrace/insight-proto-go/results/v1'
  _globals['_LOGENTRY_LABELSENTRY']._loaded_options = None
  _globals['_LOGENTRY_LABELSENTRY']._serialized_options = b'8\001'
  _globals['_LOGDETAIL'].fields_by_name['text']._loaded_options = None
  _globals['_LOGDETAIL'].fields_by_name['text']._serialized_options = b'\232\204\236\003\032firestore:\"text,omitempty\"'
  _globals['_ANNOTATIONS'].fields_by_name['start_timestamp']._loaded_options = None
  _globals['_ANNOTATIONS'].fields_by_name['start_timestamp']._serialized_options = b'\232\204\236\003$firestore:\"startTimestamp,omitempty\"'
  _globals['_ANNOTATIONS'].fields_by_name['end_timestamp']._loaded_options = None
  _globals['_ANNOTATIONS'].fields_by_name['end_timestamp']._serialized_options = b'\232\204\236\003\"firestore:\"endTimestamp,omitempty\"'
  _globals['_ANNOTATIONS'].fields_by_name['value']._loaded_options = None
  _globals['_ANNOTATIONS'].fields_by_name['value']._serialized_options = b'\232\204\236\003\033firestore:\"value,omitempty\"'
  _globals['_ANNOTATIONS'].fields_by_name['y_axis_id']._loaded_options = None
  _globals['_ANNOTATIONS'].fields_by_name['y_axis_id']._serialized_options = b'\232\204\236\003\035firestore:\"yAxisId,omitempty\"'
  _globals['_SERIES_LABELSENTRY']._loaded_options = None
  _globals['_SERIES_LABELSENTRY']._serialized_options = b'8\001'
  _globals['_METRICDATA_VALUESENTRY']._loaded_options = None
  _globals['_METRICDATA_VALUESENTRY']._serialized_options = b'8\001'
  _globals['_METRICDETAIL'].fields_by_name['text']._loaded_options = None
  _globals['_METRICDETAIL'].fields_by_name['text']._serialized_options = b'\232\204\236\003\032firestore:\"text,omitempty\"'
  _globals['_METRICDETAIL'].fields_by_name['layout']._loaded_options = None
  _globals['_METRICDETAIL'].fields_by_name['layout']._serialized_options = b'\232\204\236\003\034firestore:\"layout,omitempty\"'
  _globals['_CODEDETAIL'].fields_by_name['text']._loaded_options = None
  _globals['_CODEDETAIL'].fields_by_name['text']._serialized_options = b'\232\204\236\003\032firestore:\"text,omitempty\"'
  _globals['_MERGEREQUESTDETAIL'].fields_by_name['text']._loaded_options = None
  _globals['_MERGEREQUESTDETAIL'].fields_by_name['text']._serialized_options = b'\232\204\236\003\032firestore:\"text,omitempty\"'
  _globals['_CIDETAIL'].fields_by_name['text']._loaded_options = None
  _globals['_CIDETAIL'].fields_by_name['text']._serialized_options = b'\232\204\236\003\032firestore:\"text,omitempty\"'
  _globals['_KNOWLEDGEDETAIL'].fields_by_name['text']._loaded_options = None
  _globals['_KNOWLEDGEDETAIL'].fields_by_name['text']._serialized_options = b'\232\204\236\003\032firestore:\"text,omitempty\"'
  _globals['_TICKETDETAIL'].fields_by_name['text']._loaded_options = None
  _globals['_TICKETDETAIL'].fields_by_name['text']._serialized_options = b'\232\204\236\003\032firestore:\"text,omitempty\"'
  _globals['_TRIGGERDETAIL'].fields_by_name['trigger_source']._loaded_options = None
  _globals['_TRIGGERDETAIL'].fields_by_name['trigger_source']._serialized_options = b'\030\001\232\204\236\003\037firestore:\"logDetail,omitempty\"'
  _globals['_TRIGGERDETAIL'].fields_by_name['text']._loaded_options = None
  _globals['_TRIGGERDETAIL'].fields_by_name['text']._serialized_options = b'\232\204\236\003\032firestore:\"text,omitempty\"'
  _globals['_GENERICDETAIL'].fields_by_name['text']._loaded_options = None
  _globals['_GENERICDETAIL'].fields_by_name['text']._serialized_options = b'\232\204\236\003\032firestore:\"text,omitempty\"'
  _globals['_LOGENTRY']._serialized_start=203
  _globals['_LOGENTRY']._serialized_end=397
  _globals['_LOGENTRY_LABELSENTRY']._serialized_start=352
  _globals['_LOGENTRY_LABELSENTRY']._serialized_end=397
  _globals['_LOGDETAIL']._serialized_start=400
  _globals['_LOGDETAIL']._serialized_end=542
  _globals['_ANNOTATIONS']._serialized_start=545
  _globals['_ANNOTATIONS']._serialized_end=988
  _globals['_SERIES']._serialized_start=991
  _globals['_SERIES']._serialized_end=1216
  _globals['_SERIES_LABELSENTRY']._serialized_start=352
  _globals['_SERIES_LABELSENTRY']._serialized_end=397
  _globals['_METRICDATA']._serialized_start=1219
  _globals['_METRICDATA']._serialized_end=1389
  _globals['_METRICDATA_VALUESENTRY']._serialized_start=1344
  _globals['_METRICDATA_VALUESENTRY']._serialized_end=1389
  _globals['_LAYOUT']._serialized_start=1391
  _globals['_LAYOUT']._serialized_end=1454
  _globals['_METRICDETAIL']._serialized_start=1457
  _globals['_METRICDETAIL']._serialized_end=1845
  _globals['_USER']._serialized_start=1847
  _globals['_USER']._serialized_end=1896
  _globals['_CODEDETAIL']._serialized_start=1899
  _globals['_CODEDETAIL']._serialized_end=2159
  _globals['_MERGEREQUESTDETAIL']._serialized_start=2162
  _globals['_MERGEREQUESTDETAIL']._serialized_end=2456
  _globals['_CIDETAIL']._serialized_start=2458
  _globals['_CIDETAIL']._serialized_end=2579
  _globals['_KNOWLEDGEDETAIL']._serialized_start=2581
  _globals['_KNOWLEDGEDETAIL']._serialized_end=2659
  _globals['_TICKETDETAIL']._serialized_start=2662
  _globals['_TICKETDETAIL']._serialized_end=2843
  _globals['_TRIGGERDETAIL']._serialized_start=2846
  _globals['_TRIGGERDETAIL']._serialized_end=3040
  _globals['_GENERICDETAIL']._serialized_start=3042
  _globals['_GENERICDETAIL']._serialized_end=3118
# @@protoc_insertion_point(module_scope)
