# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: insightproto/proto/results/v1/updates.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'insightproto/proto/results/v1/updates.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2
from insightproto.proto.common.v1 import common_pb2 as insightproto_dot_proto_dot_common_dot_v1_dot_common__pb2
from insightproto.proto.results.v1 import results_pb2 as insightproto_dot_proto_dot_results_dot_v1_dot_results__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n+insightproto/proto/results/v1/updates.proto\x12\x1dinsightproto.proto.results.v1\x1a\x1bgoogle/protobuf/empty.proto\x1a)insightproto/proto/common/v1/common.proto\x1a+insightproto/proto/results/v1/results.proto\"\x9f\x01\n\rUpdateRequest\x12\x18\n\x10investigation_id\x18\x01 \x01(\t\x12\x37\n\x03org\x18\x02 \x01(\x0b\x32*.insightproto.proto.common.v1.Organisation\x12;\n\x05\x65vent\x18\x03 \x01(\x0b\x32,.insightproto.proto.results.v1.TimelineEvent2h\n\rUpdateService\x12W\n\rStreamUpdates\x12,.insightproto.proto.results.v1.UpdateRequest\x1a\x16.google.protobuf.Empty(\x01\x42\x32Z0github.com/opentrace/insight-proto-go/results/v1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'insightproto.proto.results.v1.updates_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z0github.com/opentrace/insight-proto-go/results/v1'
  _globals['_UPDATEREQUEST']._serialized_start=196
  _globals['_UPDATEREQUEST']._serialized_end=355
  _globals['_UPDATESERVICE']._serialized_start=357
  _globals['_UPDATESERVICE']._serialized_end=461
# @@protoc_insertion_point(module_scope)
